from fastapi import FastAPI
import os

__author__ = "Tiago Prata"
__copyright__ = "Copyright 2022, ABB Automacao Ltda (Brazil)"
__credits__ = ["ABB Automacao Ltda", "Tiago Prata"]
__license__ = "Copyright"
__version__ = "1.0.0"
__maintainer__ = "AssetVista Team"
__email__ = "BR-assetvista@abb.com"
__status__ = "Development (do not use in production)"

# TODO: Add comments to classes and functions
# TODO: Create test script

AMS_FOLDER_NAME = 'assetmonitors'

def _get_ams_list(folders_to_be_ignored = []):
    app_folder = os.path.dirname(os.path.realpath(__file__))
    ams_folder = os.path.join(app_folder, AMS_FOLDER_NAME)

    subfolders = []
    for folder in os.scandir(ams_folder):
        if folder.is_dir():
            if folder.name not in folders_to_be_ignored:                                        # ignoring folder from folders_to_be_ignored
                if not (folder.name.startswith('__') or folder.name.startswith('.')):           # ignoring folders starting with __ or .
                    subfolders.append(folder.name)

    return subfolders


def _include_am_routers(fastapi_app: FastAPI, ams_list):

    # Importing AMs libs
    for am in ams_list:
        import_str = ''.join(['from ', AMS_FOLDER_NAME, '.', am, ' import router as ', am])
        print(''.join(['Importing: ', import_str]))
        exec(import_str)

    # Including routers
    for am in ams_list:
        router = eval(''.join([am, '.router']))
        fastapi_app.include_router(router)

    return fastapi_app


def add_assetvista_routes(fastapi_app: FastAPI, folders_to_be_ignored = []):
    ams_list = _get_ams_list(folders_to_be_ignored)
    return _include_am_routers(fastapi_app, ams_list)